```
Usage: vcd gateway update [OPTIONS] <name>

Options:
  -n, --new-name <str>          new name of the gateway
  --description <str>           description of the gateway
  --ha-enabled / --ha-disabled  enable/disable HA for gateway.
  -h, --help                    Show this message and exit.

```
